@@ -4,7 +4,6 @@ import (
 	"bytes"
 	"encoding/json"
 	"io"
-	"io/ioutil"
 	"net/url"
 	"os"
 	"testing"
@@ -130,12 +129,9 @@ var (
 
 func TestRunAppsCreate(t *testing.T) {
 	withTestClient(t, func(config *CmdConfig, tm *tcMocks) {
-		specFile, err := ioutil.TempFile("", "spec")
+		specFile, err := os.CreateTemp(t.TempDir(), "spec")
 		require.NoError(t, err)
-		defer func() {
-			os.Remove(specFile.Name())
-			specFile.Close()
-		}()
+		defer specFile.Close()
 
 		err = json.NewEncoder(specFile).Encode(&testAppSpec)
 		require.NoError(t, err)
@@ -195,12 +191,9 @@ func TestRunAppsList(t *testing.T) {
 
 func TestRunAppsUpdate(t *testing.T) {
 	withTestClient(t, func(config *CmdConfig, tm *tcMocks) {
-		specFile, err := ioutil.TempFile("", "spec")
+		specFile, err := os.CreateTemp(t.TempDir(), "spec")
 		require.NoError(t, err)
-		defer func() {
-			os.Remove(specFile.Name())
-			specFile.Close()
-		}()
+		defer specFile.Close()
 
 		err = json.NewEncoder(specFile).Encode(&testAppSpec)
 		require.NoError(t, err)
@@ -255,6 +248,7 @@ func TestRunAppsCreateDeployment(t *testing.T) {
 				SourceCommitHash: "commit",
 			}},
 			Cause: "Manual",
+			Phase: godo.DeploymentPhase_PendingDeploy,
 			Progress: &godo.DeploymentProgress{
 				PendingSteps: 1,
 				RunningSteps: 0,
@@ -358,6 +352,7 @@ func TestRunAppsGetDeployment(t *testing.T) {
 				SourceCommitHash: "commit",
 			}},
 			Cause: "Manual",
+			Phase: godo.DeploymentPhase_PendingDeploy,
 			Progress: &godo.DeploymentProgress{
 				PendingSteps: 1,
 				RunningSteps: 0,
@@ -395,6 +390,7 @@ func TestRunAppsListDeployments(t *testing.T) {
 				SourceCommitHash: "commit",
 			}},
 			Cause: "Manual",
+			Phase: godo.DeploymentPhase_PendingDeploy,
 			Progress: &godo.DeploymentProgress{
 				PendingSteps: 1,
 				RunningSteps: 0,
@@ -439,8 +435,8 @@ func TestRunAppsGetLogs(t *testing.T) {
 
 			tc := config.Doit.(*doctl.TestConfig)
 			tc.ListenFn = func(url *url.URL, token string, schemaFunc listen.SchemaFunc, out io.Writer) listen.ListenerService {
-				assert.Equal(t, token, "aa-bb-11-cc-33")
-				assert.Equal(t, url.String(), "wss://proxy-apps-prod-ams3-001.ondigitalocean.app/?token=aa-bb-11-cc-33")
+				assert.Equal(t, "aa-bb-11-cc-33", token)
+				assert.Equal(t, "wss://proxy-apps-prod-ams3-001.ondigitalocean.app/?token=aa-bb-11-cc-33", url.String())
 				return tm.listen
 			}
 
@@ -543,7 +539,7 @@ var validAppSpec = &godo.AppSpec{
 func testTempFile(t *testing.T, data []byte) string {
 	t.Helper()
 	file := t.TempDir() + "/file"
-	err := ioutil.WriteFile(file, data, 0644)
+	err := os.WriteFile(file, data, 0644)
 	require.NoError(t, err, "writing temp file")
 	return file
 }
@@ -769,12 +765,9 @@ func TestRunAppsListAlerts(t *testing.T) {
 
 func TestRunAppsUpdateAlertDestinations(t *testing.T) {
 	withTestClient(t, func(config *CmdConfig, tm *tcMocks) {
-		destinationsFile, err := ioutil.TempFile("", "dest")
+		destinationsFile, err := os.CreateTemp(t.TempDir(), "dest")
 		require.NoError(t, err)
-		defer func() {
-			os.Remove(destinationsFile.Name())
-			destinationsFile.Close()
-		}()
+		defer destinationsFile.Close()
 
 		err = json.NewEncoder(destinationsFile).Encode(&testAlertUpdate)
 		require.NoError(t, err)
