@@ -58,7 +58,7 @@ func (m *MockBalanceService) Get(arg0 context.Context) (*godo.Balance, *godo.Res
 }
 
 // Get indicates an expected call of Get
-func (mr *MockBalanceServiceMockRecorder) Get(arg0 interface{}) *gomock.Call {
+func (mr *MockBalanceServiceMockRecorder) Get(arg0 any) *gomock.Call {
 	mr.mock.ctrl.T.Helper()
 	return mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "Get", reflect.TypeOf((*MockBalanceService)(nil).Get), arg0)
 }
