@@ -21,7 +21,6 @@ import (
 	"errors"
 	"fmt"
 	"io"
-	"io/ioutil"
 	"net/http"
 	"net/url"
 	"os"
@@ -130,19 +129,19 @@ type ServerlessProject struct {
 // ServerlessSpec describes a project.yml spec
 // reference: https://docs.nimbella.com/configuration/
 type ServerlessSpec struct {
-	Parameters  map[string]interface{} `json:"parameters,omitempty"`
-	Environment map[string]interface{} `json:"environment,omitempty"`
-	Packages    []*ServerlessPackage   `json:"packages,omitempty"`
+	Parameters  map[string]any       `json:"parameters,omitempty"`
+	Environment map[string]any       `json:"environment,omitempty"`
+	Packages    []*ServerlessPackage `json:"packages,omitempty"`
 }
 
 // ServerlessPackage ...
 type ServerlessPackage struct {
-	Name        string                 `json:"name,omitempty"`
-	Shared      bool                   `json:"shared,omitempty"`
-	Environment map[string]interface{} `json:"environment,omitempty"`
-	Parameters  map[string]interface{} `json:"parameters,omitempty"`
-	Annotations map[string]interface{} `json:"annotations,omitempty"`
-	Functions   []*ServerlessFunction  `json:"functions,omitempty"`
+	Name        string                `json:"name,omitempty"`
+	Shared      bool                  `json:"shared,omitempty"`
+	Environment map[string]any        `json:"environment,omitempty"`
+	Parameters  map[string]any        `json:"parameters,omitempty"`
+	Annotations map[string]any        `json:"annotations,omitempty"`
+	Functions   []*ServerlessFunction `json:"functions,omitempty"`
 }
 
 // ServerlessFunction ...
@@ -153,12 +152,12 @@ type ServerlessFunction struct {
 	Runtime string `json:"runtime,omitempty"`
 	// `web` can be either true or "raw". We use interface{} to support both types. If we start consuming the value we
 	// should probably define a custom type with proper validation.
-	Web         interface{}            `json:"web,omitempty"`
-	WebSecure   interface{}            `json:"webSecure,omitempty" yaml:"webSecure"`
-	Parameters  map[string]interface{} `json:"parameters,omitempty"`
-	Environment map[string]interface{} `json:"environment,omitempty"`
-	Annotations map[string]interface{} `json:"annotations,omitempty"`
-	Limits      map[string]int         `json:"limits,omitempty"`
+	Web         any            `json:"web,omitempty"`
+	WebSecure   any            `json:"webSecure,omitempty" yaml:"webSecure"`
+	Parameters  map[string]any `json:"parameters,omitempty"`
+	Environment map[string]any `json:"environment,omitempty"`
+	Annotations map[string]any `json:"annotations,omitempty"`
+	Limits      map[string]int `json:"limits,omitempty"`
 }
 
 // ProjectMetadata describes the nim project:get-metadata output structure.
@@ -196,8 +195,8 @@ type ServerlessTrigger struct {
 }
 
 type TriggerScheduledDetails struct {
-	Cron string                 `json:"cron,omitempty"`
-	Body map[string]interface{} `json:"body,omitempty"`
+	Cron string         `json:"cron,omitempty"`
+	Body map[string]any `json:"body,omitempty"`
 }
 
 type TriggerScheduledRuns struct {
@@ -232,8 +231,8 @@ type ServerlessService interface {
 	GetFunction(string, bool) (whisk.Action, []FunctionParameter, error)
 	ListFunctions(string, int, int) ([]whisk.Action, error)
 	DeleteFunction(string, bool) error
-	InvokeFunction(string, interface{}, bool, bool) (interface{}, error)
-	InvokeFunctionViaWeb(string, interface{}) error
+	InvokeFunction(string, any, bool, bool) (any, error)
+	InvokeFunctionViaWeb(string, any) error
 	ListActivations(whisk.ActivationListOptions) ([]whisk.Activation, error)
 	GetActivationCount(whisk.ActivationCountOptions) (whisk.ActivationCount, error)
 	GetActivation(string) (whisk.Activation, error)
@@ -316,11 +315,11 @@ var (
 
 // ServerlessOutput contains the output returned from calls to the sandbox plugin.
 type ServerlessOutput struct {
-	Table     []map[string]interface{} `json:"table,omitempty"`
-	Captured  []string                 `json:"captured,omitempty"`
-	Formatted []string                 `json:"formatted,omitempty"`
-	Entity    interface{}              `json:"entity,omitempty"`
-	Error     string                   `json:"error,omitempty"`
+	Table     []map[string]any `json:"table,omitempty"`
+	Captured  []string         `json:"captured,omitempty"`
+	Formatted []string         `json:"formatted,omitempty"`
+	Entity    any              `json:"entity,omitempty"`
+	Error     string           `json:"error,omitempty"`
 }
 
 // NewServerlessService returns a configured ServerlessService.
@@ -418,7 +417,7 @@ func (s *serverlessService) InstallServerless(leafCredsDir string, upgrading boo
 	// will require an additional copy rather than a simple rename.
 
 	os.Mkdir(filepath.Dir(serverlessDir), 0700) // in case using config dir and it doesn't exist yet
-	tmp, err := ioutil.TempDir(filepath.Dir(serverlessDir), "sbx-install")
+	tmp, err := os.MkdirTemp(filepath.Dir(serverlessDir), "sbx-install")
 	if err != nil {
 		return err
 	}
@@ -778,6 +777,9 @@ func (s *serverlessService) GetHostInfo(APIHost string) (ServerlessHostInfo, err
 	}
 	defer resp.Body.Close()
 	body, err := io.ReadAll(resp.Body)
+	if err != nil {
+		return ServerlessHostInfo{}, err
+	}
 	var result ServerlessHostInfo
 	err = json.Unmarshal(body, &result)
 	return result, err
@@ -896,8 +898,8 @@ func (s *serverlessService) DeletePackage(name string, recursive bool) error {
 }
 
 // InvokeFunction invokes a function via POST with authentication
-func (s *serverlessService) InvokeFunction(name string, params interface{}, blocking bool, result bool) (interface{}, error) {
-	var empty map[string]interface{}
+func (s *serverlessService) InvokeFunction(name string, params any, blocking bool, result bool) (any, error) {
+	var empty map[string]any
 	err := initWhisk(s)
 	if err != nil {
 		return empty, err
@@ -907,7 +909,7 @@ func (s *serverlessService) InvokeFunction(name string, params interface{}, bloc
 }
 
 // InvokeFunctionViaWeb invokes a function via GET using its web URL (or error if not a web function)
-func (s *serverlessService) InvokeFunctionViaWeb(name string, params interface{}) error {
+func (s *serverlessService) InvokeFunctionViaWeb(name string, params any) error {
 	// Get the function so we can use its metadata in formulating the request
 	theFunction, _, err := s.GetFunction(name, false)
 	if err != nil {
@@ -939,7 +941,7 @@ func (s *serverlessService) InvokeFunctionViaWeb(name string, params interface{}
 	// Add params, if any
 	if params != nil {
 		encoded := url.Values{}
-		for key, val := range params.(map[string]interface{}) {
+		for key, val := range params.(map[string]any) {
 			stringVal, ok := val.(string)
 			if !ok {
 				return fmt.Errorf("the value of '%s' is not a string; web invocation is not possible", key)
@@ -1162,7 +1164,7 @@ func readTopLevel(project *ServerlessProject) error {
 		Config   = "project.yml"
 		Packages = "packages"
 	)
-	files, err := ioutil.ReadDir(project.ProjectPath)
+	files, err := os.ReadDir(project.ProjectPath)
 	if err != nil {
 		return err
 	}
@@ -1185,7 +1187,7 @@ func readTopLevel(project *ServerlessProject) error {
 func readProjectConfig(configPath string) (*ServerlessSpec, error) {
 	spec := ServerlessSpec{}
 	// reading config file content
-	content, err := ioutil.ReadFile(configPath)
+	content, err := os.ReadFile(configPath)
 	if err != nil {
 		return nil, err
 	}
@@ -1262,7 +1264,7 @@ func (s *serverlessService) CredentialsPath() string {
 	return s.credsDir
 }
 
-// ReadCredentials reads the current serverless credentials from the appropriate 'creds' diretory
+// ReadCredentials reads the current serverless credentials from the appropriate 'creds' directory
 func (s *serverlessService) ReadCredentials() (ServerlessCredentials, error) {
 	creds := ServerlessCredentials{}
 	credsPath := filepath.Join(s.credsDir, CredentialsFile)
@@ -1300,7 +1302,7 @@ func serverlessUptodate(serverlessDir string) bool {
 // Otherwise, returns the version string stored in the serverless directory.
 func GetCurrentServerlessVersion(serverlessDir string) string {
 	versionFile := filepath.Join(serverlessDir, "version")
-	contents, err := ioutil.ReadFile(versionFile)
+	contents, err := os.ReadFile(versionFile)
 	if err != nil {
 		return "0"
 	}
