@@ -4,7 +4,6 @@ import (
 	"bytes"
 	"encoding/json"
 	"fmt"
-	"io/ioutil"
 	"net/http"
 	"net/http/httptest"
 	"net/http/httputil"
@@ -154,12 +153,13 @@ var (
 			Default:     true,
 		}},
 	}
+
 	testAppsOutput = `ID                                      Spec Name    Default Ingress    Active Deployment ID                    In Progress Deployment ID    Created At                       Updated At
 93a37175-f520-4a12-a7ad-26e63491dbf4    test                            f4e37431-a0f4-458f-8f9f-5c9a61d8562f                                 1970-01-01 00:00:01 +0000 UTC    1970-01-01 00:00:01 +0000 UTC`
-	testDeploymentsOutput = `ID                                      Cause     Progress    Created At                       Updated At
-f4e37431-a0f4-458f-8f9f-5c9a61d8562f    Manual    0/1         1970-01-01 00:00:01 +0000 UTC    1970-01-01 00:00:01 +0000 UTC`
-	testActiveDeploymentOutput = `ID                                      Cause     Progress    Created At                       Updated At
-f4e37431-a0f4-458f-8f9f-5c9a61d8562f    Manual    1/1         1970-01-01 00:00:01 +0000 UTC    1970-01-01 00:00:01 +0000 UTC`
+	testDeploymentsOutput = `ID                                      Cause     Progress    Phase             Created At                       Updated At
+f4e37431-a0f4-458f-8f9f-5c9a61d8562f    Manual    0/1         PENDING_DEPLOY    1970-01-01 00:00:01 +0000 UTC    1970-01-01 00:00:01 +0000 UTC`
+	testActiveDeploymentOutput = `ID                                      Cause     Progress    Phase     Created At                       Updated At
+f4e37431-a0f4-458f-8f9f-5c9a61d8562f    Manual    1/1         ACTIVE    1970-01-01 00:00:01 +0000 UTC    1970-01-01 00:00:01 +0000 UTC`
 	testRegionsOutput = `Region    Label        Continent    Data Centers    Is Disabled?    Reason (if disabled)    Is Default?
 ams       Amsterdam    Europe       [ams3]          false                                   true`
 )
@@ -249,12 +249,9 @@ var _ = suite("apps/create", func(t *testing.T, when spec.G, it spec.S) {
 	})
 
 	it("creates an app", func() {
-		specFile, err := ioutil.TempFile("", "spec")
+		specFile, err := os.CreateTemp(t.TempDir(), "spec")
 		require.NoError(t, err)
-		defer func() {
-			os.Remove(specFile.Name())
-			specFile.Close()
-		}()
+		defer specFile.Close()
 
 		err = json.NewEncoder(specFile).Encode(&testAppSpec)
 		require.NoError(t, err)
@@ -276,12 +273,10 @@ var _ = suite("apps/create", func(t *testing.T, when spec.G, it spec.S) {
 	})
 	when("the wait flag is passed", func() {
 		it("creates an app and polls for status", func() {
-			specFile, err := ioutil.TempFile("", "spec")
+			specFile, err := os.CreateTemp(t.TempDir(), "spec")
 			require.NoError(t, err)
-			defer func() {
-				os.Remove(specFile.Name())
-				specFile.Close()
-			}()
+			defer specFile.Close()
+
 			err = json.NewEncoder(specFile).Encode(&testAppSpec)
 			require.NoError(t, err)
 			cmd := exec.Command(builtBinaryPath,
@@ -301,12 +296,10 @@ var _ = suite("apps/create", func(t *testing.T, when spec.G, it spec.S) {
 	})
 	when("the upsert flag is passed", func() {
 		it("creates an app or updates if already exists", func() {
-			specFile, err := ioutil.TempFile("", "spec")
+			specFile, err := os.CreateTemp(t.TempDir(), "spec")
 			require.NoError(t, err)
-			defer func() {
-				os.Remove(specFile.Name())
-				specFile.Close()
-			}()
+			defer specFile.Close()
+
 			err = json.NewEncoder(specFile).Encode(&testAppSpec)
 			require.NoError(t, err)
 			cmd := exec.Command(builtBinaryPath,
@@ -400,12 +393,9 @@ var _ = suite("apps/create-upsert", func(t *testing.T, when spec.G, it spec.S) {
 	})
 
 	it("uses upsert to update existing app", func() {
-		specFile, err := ioutil.TempFile("", "spec")
+		specFile, err := os.CreateTemp(t.TempDir(), "spec")
 		require.NoError(t, err)
-		defer func() {
-			os.Remove(specFile.Name())
-			specFile.Close()
-		}()
+		defer specFile.Close()
 
 		err = json.NewEncoder(specFile).Encode(&testAppSpec)
 		require.NoError(t, err)
@@ -611,12 +601,9 @@ var _ = suite("apps/update", func(t *testing.T, when spec.G, it spec.S) {
 	})
 
 	it("updates an app", func() {
-		specFile, err := ioutil.TempFile("", "spec")
+		specFile, err := os.CreateTemp(t.TempDir(), "spec")
 		require.NoError(t, err)
-		defer func() {
-			os.Remove(specFile.Name())
-			specFile.Close()
-		}()
+		defer specFile.Close()
 
 		err = json.NewEncoder(specFile).Encode(&testAppSpec)
 		require.NoError(t, err)
@@ -639,12 +626,10 @@ var _ = suite("apps/update", func(t *testing.T, when spec.G, it spec.S) {
 	})
 	when("the wait flag is passed", func() {
 		it("updates an app and polls for status", func() {
-			specFile, err := ioutil.TempFile("", "spec")
+			specFile, err := os.CreateTemp(t.TempDir(), "spec")
 			require.NoError(t, err)
-			defer func() {
-				os.Remove(specFile.Name())
-				specFile.Close()
-			}()
+			defer specFile.Close()
+
 			err = json.NewEncoder(specFile).Encode(&testAppSpec)
 			require.NoError(t, err)
 			cmd := exec.Command(builtBinaryPath,
@@ -1355,8 +1340,8 @@ var _ = suite("apps/upgrade-buildpack", func(t *testing.T, when spec.G, it spec.
 			upgraded buildpack digitalocean/go. 2 components were affected: [api www].
 			triggered a new deployment to apply the upgrade:
 			
-			ID                                      Cause     Progress    Created At                       Updated At
-			f4e37431-a0f4-458f-8f9f-5c9a61d8562f    Manual    0/1         1970-01-01 00:00:01 +0000 UTC    1970-01-01 00:00:01 +0000 UTC
+			ID                                      Cause     Progress    Phase             Created At                       Updated At
+			f4e37431-a0f4-458f-8f9f-5c9a61d8562f    Manual    0/1         PENDING_DEPLOY    1970-01-01 00:00:01 +0000 UTC    1970-01-01 00:00:01 +0000 UTC
 		`), string(output))
 		expect.NoError(err)
 	})
